package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.DoumuEvaluate;

/**
 * 订单评价Service接口
 * 
 * @author boman
 * @date 2024-01-22
 */
public interface IDoumuEvaluateService 
{
    /**
     * 查询订单评价
     * 
     * @param evaluateId 订单评价主键
     * @return 订单评价
     */
    public DoumuEvaluate selectDoumuEvaluateByEvaluateId(Long evaluateId);

    /**
     * 查询订单评价列表
     * 
     * @param doumuEvaluate 订单评价
     * @return 订单评价集合
     */
    public List<DoumuEvaluate> selectDoumuEvaluateList(DoumuEvaluate doumuEvaluate);

    /**
     * 新增订单评价
     * 
     * @param doumuEvaluate 订单评价
     * @return 结果
     */
    public int insertDoumuEvaluate(DoumuEvaluate doumuEvaluate);

    /**
     * 修改订单评价
     * 
     * @param doumuEvaluate 订单评价
     * @return 结果
     */
    public int updateDoumuEvaluate(DoumuEvaluate doumuEvaluate);

    /**
     * 批量删除订单评价
     * 
     * @param evaluateIds 需要删除的订单评价主键集合
     * @return 结果
     */
    public int deleteDoumuEvaluateByEvaluateIds(Long[] evaluateIds);

    /**
     * 删除订单评价信息
     * 
     * @param evaluateId 订单评价主键
     * @return 结果
     */
    public int deleteDoumuEvaluateByEvaluateId(Long evaluateId);
}
