package com.ruoyi.web.controller.doumu;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.DoumuEvaluate;
import com.ruoyi.system.service.IDoumuEvaluateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单评价Controller
 * 
 * @author boman
 * @date 2024-01-22
 */
@RestController
@RequestMapping("/system/evaluate")
public class DoumuEvaluateController extends BaseController
{
    @Autowired
    private IDoumuEvaluateService doumuEvaluateService;

    /**
     * 查询订单评价列表
     */
    @PreAuthorize("@ss.hasPermi('system:evaluate:list')")
    @GetMapping("/list")
    public TableDataInfo list(DoumuEvaluate doumuEvaluate)
    {
        startPage();
        List<DoumuEvaluate> list = doumuEvaluateService.selectDoumuEvaluateList(doumuEvaluate);
        return getDataTable(list);
    }

    /**
     * 导出订单评价列表
     */
    @PreAuthorize("@ss.hasPermi('system:evaluate:export')")
    @Log(title = "订单评价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DoumuEvaluate doumuEvaluate)
    {
        List<DoumuEvaluate> list = doumuEvaluateService.selectDoumuEvaluateList(doumuEvaluate);
        ExcelUtil<DoumuEvaluate> util = new ExcelUtil<DoumuEvaluate>(DoumuEvaluate.class);
        util.exportExcel(response, list, "订单评价数据");
    }

    /**
     * 获取订单评价详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:evaluate:query')")
    @GetMapping(value = "/{evaluateId}")
    public AjaxResult getInfo(@PathVariable("evaluateId") Long evaluateId)
    {
        return success(doumuEvaluateService.selectDoumuEvaluateByEvaluateId(evaluateId));
    }

    /**
     * 新增订单评价
     */
    @PreAuthorize("@ss.hasPermi('system:evaluate:add')")
    @Log(title = "订单评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DoumuEvaluate doumuEvaluate)
    {
        return toAjax(doumuEvaluateService.insertDoumuEvaluate(doumuEvaluate));
    }

    /**
     * 修改订单评价
     */
    @PreAuthorize("@ss.hasPermi('system:evaluate:edit')")
    @Log(title = "订单评价", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody DoumuEvaluate doumuEvaluate)
    {
        return toAjax(doumuEvaluateService.updateDoumuEvaluate(doumuEvaluate));
    }

    /**
     * 删除订单评价
     */
    @PreAuthorize("@ss.hasPermi('system:evaluate:remove')")
    @Log(title = "订单评价", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{evaluateIds}")
    public AjaxResult remove(@PathVariable Long[] evaluateIds)
    {
        return toAjax(doumuEvaluateService.deleteDoumuEvaluateByEvaluateIds(evaluateIds));
    }
}
